@@ -14,7 +14,7 @@ from checkov.graph.terraform.graph_builder.graph_components.generic_resource_enc
 from checkov.graph.terraform.graph_builder.utils import is_local_path
 from checkov.graph.terraform.utils.utils import get_referenced_vertices_in_value, update_dictionary_attribute, \
     join_trimmed_strings, \
-    filter_sub_keys
+    filter_sub_keys, extend_referenced_vertices_with_tf_vars
 from checkov.graph.terraform.utils.utils import remove_index_pattern_from_str, calculate_hash
 from checkov.graph.terraform.variable_rendering.renderer import VariableRenderer
 
@@ -79,12 +79,15 @@ class LocalGraph:
                     variable_dir = os.path.dirname(variable_vertex.path)
                     if self.module_dependency_map.get(variable_dir) == module_vertex.path:
                         attribute_value = module_vertex.attributes[attribute_name]
-                        if get_referenced_vertices_in_value(value=attribute_value, aliases={},
-                                                            resources_types=self.get_resources_types_in_graph()):
+                        has_var_reference = get_referenced_vertices_in_value(value=attribute_value, aliases={},
+                                                            resources_types=self.get_resources_types_in_graph())
+                        if has_var_reference:
                             undetermined_values.append(
                                 {'module_vertex_id': module_vertex_id, 'attribute_name': attribute_name,
                                  'variable_vertex_id': variable_vertex_id})
-                        else:
+                        var_default_value = self.vertices[variable_vertex_id].attributes.get("default")
+                        if not has_var_reference or not var_default_value or get_referenced_vertices_in_value(value=var_default_value, aliases={},
+                                                            resources_types=self.get_resources_types_in_graph()):
                             self.update_vertex_attribute(variable_vertex_id, 'default', attribute_value,
                                                          module_vertex_id, attribute_name)
         return undetermined_values
@@ -144,7 +147,7 @@ class LocalGraph:
                 referenced_vertices = get_referenced_vertices_in_value(value=vertex.attributes[attribute_key],
                                                                        aliases=aliases,
                                                                        resources_types=self.get_resources_types_in_graph())
-
+                extend_referenced_vertices_with_tf_vars(referenced_vertices)
                 for vertex_reference in referenced_vertices:
                     # for certain blocks such as data and resource, the block name is composed from several parts.
                     # the purpose of the loop is to avoid not finding the node if the name has several parts
@@ -305,7 +308,19 @@ class LocalGraph:
         res = []
         for vertex in end_vertices:
             res.extend(self.in_edges.get(vertex, []))
-        return res
+        return self.sort_edged_by_dest_out_degree(res)
+
+    def sort_edged_by_dest_out_degree(self, edges):
+        edged_by_out_degree = {}
+        for edge in edges:
+            dest_out_degree = len(self.out_edges.get(edge.dest))
+            if not edged_by_out_degree.get(dest_out_degree):
+                edged_by_out_degree[dest_out_degree] = []
+            edged_by_out_degree[dest_out_degree].append(edge)
+        sorted_edges = []
+        for degree in sorted(edged_by_out_degree.keys()):
+            sorted_edges.extend(edged_by_out_degree[degree])
+        return sorted_edges
 
     def update_vertex_attribute(self, vertex_index, attribute_key, attribute_value, change_origin_id,
                                 attribute_at_dest):
@@ -320,14 +335,24 @@ class LocalGraph:
         for vertex in self.vertices:
             changed_attributes = list(vertex.changed_attributes.keys())
             changed_attributes = filter_sub_keys(changed_attributes)
-            updated_config = deepcopy(vertex.config)
+            self.update_vertex_config(vertex, changed_attributes)
+
+    @staticmethod
+    def update_vertex_config(vertex, changed_attributes):
+        updated_config = deepcopy(vertex.config)
+        if vertex.block_type != BlockType.LOCALS:
             for name_part in vertex.name.split('.'):
                 updated_config = updated_config.get(name_part)
-            for changed_attribute in changed_attributes:
-                new_value = vertex.attributes.get(changed_attribute, None)
-                if new_value is not None:
-                    updated_config = update_dictionary_attribute(updated_config, changed_attribute, [new_value])
+        for changed_attribute in changed_attributes:
+            new_value = vertex.attributes.get(changed_attribute, None)
+            if new_value is not None:
+                if vertex.block_type == BlockType.LOCALS:
+                    changed_attribute = changed_attribute.replace(vertex.name + ".", '')
+                updated_config = update_dictionary_attribute(updated_config, changed_attribute, new_value)
 
+        if len(changed_attributes) > 0:
+            if vertex.block_type == BlockType.LOCALS:
+                updated_config = updated_config.get(vertex.name)
             update_dictionary_attribute(vertex.config, vertex.name, updated_config)
 
     def get_resources_types_in_graph(self):
