@@ -14,7 +14,7 @@ class ApiServerProfiling(BaseK8Check):
         return f'{conf["parent"]} - {conf["name"]}'
 
     def scan_spec_conf(self, conf):
-        if "command" in conf:
+        if conf.get("command") is not None:
             if "kube-apiserver" in conf["command"]:
                 if "--profiling=true" in conf["command"] or "--profiling=false" not in conf["command"]:
                     return CheckResult.FAILED
